"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _startCase2 = _interopRequireDefault(require("lodash/startCase"));

var _react = _interopRequireDefault(require("react"));

var _core = require("@runly/core");

var _accounting = require("accounting");

var _loading = _interopRequireDefault(require("./loading"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const RunProgress = ({
  org,
  runId
}) => {
  const {
    run
  } = (0, _core.useRunConnection)(org, runId);

  if (!run) {
    return /*#__PURE__*/_react.default.createElement(_loading.default, null);
  }

  console.log(run);

  if (isProgressEmpty(run.progress)) {
    return /*#__PURE__*/_react.default.createElement("h4", null, /*#__PURE__*/_react.default.createElement("span", {
      className: `badge badge${typeFromStatus((0, _startCase2.default)(run.state))}`
    }, run.state));
  }

  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("div", {
    className: "progress"
  }, /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: run.state == "Running",
    isSuccess: true,
    value: run.progress.success,
    total: run.progress.total
  }), /*#__PURE__*/_react.default.createElement(Progress, {
    isRunning: run.state == "Running",
    value: run.progress.failed,
    total: run.progress.total
  })), /*#__PURE__*/_react.default.createElement(ProgressText, run.progress));
};

const Progress = ({
  isRunning,
  isSuccess,
  value,
  total
}) => {
  if (!value) return null;
  const percentage = value / total * 100.0;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: `progress-bar ${isSuccess ? "bg-success" : "bg-danger"} ${isRunning ? "progress-bar-striped progress-bar-animated" : ""}`,
    role: "progressbar",
    style: {
      width: `${percentage}%`
    },
    "aria-valuenow": value,
    "aria-valuemin": value,
    "aria-valuemax": total
  });
};

const ProgressText = ({
  success,
  failed,
  total
}) => {
  let text = "";

  if (success && success === total) {
    return /*#__PURE__*/_react.default.createElement("small", {
      className: "text-muted"
    }, (0, _accounting.formatNumber)(success), " successful items");
  }

  if (failed && failed === total) {
    return /*#__PURE__*/_react.default.createElement("small", {
      className: "text-muted"
    }, (0, _accounting.formatNumber)(failed), " failed items");
  }

  if (success) {
    text += `${(0, _accounting.formatNumber)(success)} successful`;
  }

  if (failed) {
    if (text) {
      text += `, ${(0, _accounting.formatNumber)(failed)} failed`;
    } else {
      text += `${(0, _accounting.formatNumber)(failed)} failed`;
    }
  }

  if (total) {
    if (text) {
      text += ` out of ${(0, _accounting.formatNumber)(total)}`;
    } else {
      text += `${(0, _accounting.formatNumber)(total)} unprocessed`;
    }
  }

  if (!text) return null;
  return /*#__PURE__*/_react.default.createElement("small", {
    className: "text-muted"
  }, text);
};

function typeFromStatus(runStatus) {
  switch (runStatus) {
    case "Enqueued":
      return "-secondary";

    case "Running":
      return "-primary";

    case "Successful":
      return "-success";

    case "Failed":
      return "-danger";

    case "Cancelled":
      return "-warning";

    case "TimedOut":
      return "-danger";

    case "Error":
      return "-danger";

    default:
      return "";
  }
}

function isProgressEmpty(progress) {
  if (!progress) return true;
  if (!progress.success && !progress.failed && !progress.total) return true;
  return false;
}

var _default = RunProgress;
exports.default = _default;